Module errors

Module errors 

Types representing specific types of errors.

Structs

ParseErrorEithereasy-functions
The error type representing a parse error for one of the operands specified to the compare() function.

Enums

GeneratorError
An error type representing an error while generating a fuzzy hash.
GeneratorErrorCategory
An error category type for a generator error.
GeneratorOrIOErroreasy-functions and std
The error type describing either a generator error or an I/O error.
OperationError
An error type representing an error (generally) while processing a fuzzy hash.
ParseError
An error type representing an error (generally) while parsing a fuzzy hash.
ParseErrorSideeasy-functions
The operand (side) which caused a parse error.