DataLengthValidity

Enum DataLengthValidity 

pub enum DataLengthValidity {
    TooSmall,
    ValidWhenOptimistic,
    Valid,
    TooLarge,
}
Denotes validity depending on the data length.

Variants



TooSmall

Too small to process (even in the default optimistic mode).



ValidWhenOptimistic

Valid on the optimistic mode (default) but invalid (too small) on the conservative mode.



Valid

Valid also on the conservative mode (i.e. valid on all modes).



TooLarge

Too large to process.

Implementations

Source

impl DataLengthValidity

pub fn new<const SIZE_BUCKETS: usize>(len: u32) -> DataLengthValidity
where FuzzyHashBucketsInfo<SIZE_BUCKETS>: FuzzyHashBucketMapper, LengthProcessingInfo<SIZE_BUCKETS>: ConstrainedLengthProcessingInfo,

Gets the validity value depending on the input data length and the number of buckets.

The SIZE_BUCKETS parameter shall be the one of the bucket size constants in tlsh::buckets.

pub fn is_err(&self) -> bool

Checks whether this validity value is a hard error (i.e. whether this is an error on all modes).

pub fn is_err_on(&self, mode: DataLengthProcessingMode) -> bool

Checks whether this validity value is an error on the specified processing mode.