Types representing specific types of errors.
Structs
- Parse
Error Either easy-functions - The error type representing a parse error for one of the operands
specified to the
compare()function.
Enums
- Generator
Error - An error type representing an error while generating a fuzzy hash.
- Generator
Error Category - An error category type for a generator error.
- Generator
OrIO Error easy-functionsandstd - The error type describing either a generator error or an I/O error.
- Operation
Error - An error type representing an error (generally) while processing a fuzzy hash.
- Parse
Error - An error type representing an error (generally) while parsing a fuzzy hash.
- Parse
Error Side easy-functions - The operand (side) which caused a parse error.